@@ -1,6 +1,6 @@
 ActiveRecord::Base.establish_connection(
-  adapter: 'sqlite3',
-  database: File.join(File.dirname(__FILE__), 'test.db')
+  adapter: "sqlite3",
+  database: ":memory:",
 )
 
 migration_class =
