@@ -1,7 +1,6 @@
-require 'factory_bot/declaration/static'
-require 'factory_bot/declaration/dynamic'
-require 'factory_bot/declaration/association'
-require 'factory_bot/declaration/implicit'
+require "factory_bot/declaration/dynamic"
+require "factory_bot/declaration/association"
+require "factory_bot/declaration/implicit"
 
 module FactoryBot
   # @api private
@@ -18,6 +17,7 @@ module FactoryBot
     end
 
     protected
+
     attr_reader :ignored
   end
 end
