@@ -9,7 +9,7 @@ module FactoryBot
     end
 
     def run(runner_strategy = @strategy, &block)
-      factory = FactoryBot.factory_by_name(@name)
+      factory = FactoryBot::Internal.factory_by_name(@name)
 
       factory.compile
 
@@ -22,10 +22,10 @@ module FactoryBot
         strategy: runner_strategy,
         traits: @traits,
         overrides: @overrides,
-        factory: factory
+        factory: factory,
       }
 
-      ActiveSupport::Notifications.instrument('factory_bot.run_factory', instrumentation_payload) do
+      ActiveSupport::Notifications.instrument("factory_bot.run_factory", instrumentation_payload) do
         factory.run(runner_strategy, @overrides, &block)
       end
     end
