@@ -31,7 +31,8 @@ module FactoryBot
       def result(evaluation)
         evaluation.object.tap do |instance|
           stub_database_interaction_on_result(instance)
-          clear_changed_attributes_on_result(instance)
+          set_timestamps(instance)
+          clear_changes_information(instance)
           evaluation.notify(:after_stub, instance)
         end
       end
@@ -43,15 +44,17 @@ module FactoryBot
       end
 
       def stub_database_interaction_on_result(result_instance)
-        result_instance.id ||= next_id
+        if has_settable_id?(result_instance)
+          result_instance.id ||= next_id
+        end
 
         result_instance.instance_eval do
           def persisted?
-            !new_record?
+            true
           end
 
           def new_record?
-            id.nil?
+            false
           end
 
           def destroyed?
@@ -60,46 +63,44 @@ module FactoryBot
 
           DISABLED_PERSISTENCE_METHODS.each do |write_method|
             define_singleton_method(write_method) do |*args|
-              raise "stubbed models are not allowed to access the database - #{self.class}##{write_method}(#{args.join(",")})"
-            end
-          end
-        end
-
-        created_at_missing_default = result_instance.respond_to?(:created_at) && !result_instance.created_at
-
-        if created_at_missing_default
-          result_instance.instance_eval do
-            def created_at
-              @created_at ||= Time.now.in_time_zone
-            end
-          end
-        end
-
-        has_updated_at = result_instance.respond_to?(:updated_at)
-        updated_at_no_default = has_updated_at && !result_instance.updated_at
-
-        if updated_at_no_default
-          result_instance.instance_eval do
-            def updated_at
-              @updated_at ||= Time.current
+              raise "stubbed models are not allowed to access the database - "\
+                    "#{self.class}##{write_method}(#{args.join(',')})"
             end
           end
         end
       end
 
-      def clear_changed_attributes_on_result(result_instance)
-        unless result_instance.respond_to?(:clear_changes_information)
-          result_instance.extend ActiveModelDirtyBackport
+      def has_settable_id?(result_instance)
+        !result_instance.class.respond_to?(:primary_key) ||
+          result_instance.class.primary_key
+      end
+
+      def clear_changes_information(result_instance)
+        if result_instance.respond_to?(:clear_changes_information)
+          result_instance.clear_changes_information
+        end
+      end
+
+      def set_timestamps(result_instance)
+        if missing_created_at?(result_instance)
+          result_instance.created_at = Time.current
         end
 
-        result_instance.clear_changes_information
+        if missing_updated_at?(result_instance)
+          result_instance.updated_at = Time.current
+        end
       end
-    end
 
-    module ActiveModelDirtyBackport
-      def clear_changes_information
-        @previously_changed = ActiveSupport::HashWithIndifferentAccess.new
-        @changed_attributes = ActiveSupport::HashWithIndifferentAccess.new
+      def missing_created_at?(result_instance)
+        result_instance.respond_to?(:created_at) &&
+          result_instance.respond_to?(:created_at=) &&
+          result_instance.created_at.blank?
+      end
+
+      def missing_updated_at?(result_instance)
+        result_instance.respond_to?(:updated_at) &&
+          result_instance.respond_to?(:updated_at=) &&
+          result_instance.updated_at.blank?
       end
     end
   end
