@@ -4,12 +4,14 @@ module FactoryBot
     attr_reader :name, :definition
 
     def initialize(name, &block)
-      @name = name
+      @name = name.to_s
       @block = block
       @definition = Definition.new(@name)
-
       proxy = FactoryBot::DefinitionProxy.new(@definition)
-      proxy.instance_eval(&@block) if block_given?
+
+      if block_given?
+        proxy.instance_eval(&@block)
+      end
     end
 
     delegate :add_callback, :declare_attribute, :to_create, :define_trait, :constructor,
@@ -25,6 +27,7 @@ module FactoryBot
     end
 
     protected
+
     attr_reader :block
   end
 end
