@@ -4,9 +4,9 @@ describe "declaring attributes on a Factory that are private methods on Object"
 
     FactoryBot.define do
       factory :website do
-        system false
-        link   "http://example.com"
-        sleep  15
+        system { false }
+        link   { "http://example.com" }
+        sleep  { 15 }
       end
     end
   end
@@ -20,12 +20,12 @@ end
 
 describe "assigning overrides that are also private methods on object" do
   before do
-    define_model("Website",  format: :string, y: :integer, more_format: :string, some_funky_method: :string)
+    define_model("Website", format: :string, y: :integer, more_format: :string, some_funky_method: :string)
 
     Object.class_eval do
       private
-      def some_funky_method(args)
-      end
+
+      def some_funky_method(args); end
     end
 
     FactoryBot.define do
@@ -46,7 +46,8 @@ describe "assigning overrides that are also private methods on object" do
   its(:some_funky_method) { should eq "foobar!" }
 end
 
-describe "accessing methods from the instance within a dynamic attribute that is also a private method on object" do
+describe "accessing methods from the instance within a dynamic attribute "\
+         "that is also a private method on object" do
   before do
     define_model("Website", more_format: :string) do
       def format
