@@ -1,10 +1,10 @@
 describe "build multiple instances" do
   before do
-    define_model('Post', title: :string, position: :integer)
+    define_model("Post", title: :string, position: :integer)
 
     FactoryBot.define do
       factory(:post) do |post|
-        post.title "Through the Looking Glass"
+        post.title { "Through the Looking Glass" }
         post.position { rand(10**4) }
       end
     end
@@ -46,7 +46,7 @@ describe "build multiple instances" do
     end
 
     it "correctly uses the set value" do
-      subject.each_with_index do |record, index|
+      subject.each do |record|
         expect(record.position).to eq record.id
       end
     end
