@@ -2,9 +2,9 @@ describe "a built instance" do
   include FactoryBot::Syntax::Methods
 
   before do
-    define_model('User')
+    define_model("User")
 
-    define_model('Post', user_id: :integer) do
+    define_model("Post", user_id: :integer) do
       belongs_to :user
     end
 
@@ -21,39 +21,32 @@ describe "a built instance" do
 
   it { should be_new_record }
 
-  context "when the :use_parent_strategy config option has not been set" do
-    before { FactoryBot.use_parent_strategy = nil }
-
+  context "when the :use_parent_strategy config option is set to false" do
     it "assigns and saves associations" do
-      expect(subject.user).to be_kind_of(User)
-      expect(subject.user).not_to be_new_record
+      with_temporary_assignment(FactoryBot, :use_parent_strategy, false) do
+        expect(subject.user).to be_kind_of(User)
+        expect(subject.user).not_to be_new_record
+      end
     end
   end
 
-  context "when the :use_parent_strategy config option has been enabled" do
-    before { FactoryBot.use_parent_strategy = true }
-
+  context "when the :use_parent_strategy config option is set to true" do
     it "assigns but does not save associations" do
-      expect(subject.user).to be_kind_of(User)
-      expect(subject.user).to be_new_record
+      with_temporary_assignment(FactoryBot, :use_parent_strategy, true) do
+        expect(subject.user).to be_kind_of(User)
+        expect(subject.user).to be_new_record
+      end
     end
   end
-
-  it "assigns but does not save associations when using parent strategy" do
-    FactoryBot.use_parent_strategy = true
-
-    expect(subject.user).to be_kind_of(User)
-    expect(subject.user).to be_new_record
-  end
 end
 
 describe "a built instance with strategy: :create" do
   include FactoryBot::Syntax::Methods
 
   before do
-    define_model('User')
+    define_model("User")
 
-    define_model('Post', user_id: :integer) do
+    define_model("Post", user_id: :integer) do
       belongs_to :user
     end
 
@@ -80,7 +73,7 @@ describe "calling `build` with a block" do
   include FactoryBot::Syntax::Methods
 
   before do
-    define_model('Company', name: :string)
+    define_model("Company", name: :string)
 
     FactoryBot.define do
       factory :company
@@ -88,8 +81,8 @@ describe "calling `build` with a block" do
   end
 
   it "passes the built instance" do
-    build(:company, name: 'thoughtbot') do |company|
-      expect(company.name).to eq('thoughtbot')
+    build(:company, name: "thoughtbot") do |company|
+      expect(company.name).to eq("thoughtbot")
     end
   end
 
