@@ -2,9 +2,9 @@ describe "a generated stub instance" do
   include FactoryBot::Syntax::Methods
 
   before do
-    define_model('User')
+    define_model("User")
 
-    define_model('Post', title:   :string,
+    define_model("Post", title:   :string,
                          body:    :string,
                          age:     :integer,
                          user_id: :integer,
@@ -23,14 +23,14 @@ describe "a generated stub instance" do
     end
   end
 
-  subject { build_stubbed(:post, title: 'overridden title') }
+  subject { build_stubbed(:post, title: "overridden title") }
 
   it "assigns a default attribute" do
-    expect(subject.body).to eq 'default body'
+    expect(subject.body).to eq "default body"
   end
 
   it "assigns an overridden attribute" do
-    expect(subject.title).to eq 'overridden title'
+    expect(subject.title).to eq "overridden title"
   end
 
   it "assigns associations" do
@@ -113,7 +113,7 @@ describe "calling `build_stubbed` with a block" do
   include FactoryBot::Syntax::Methods
 
   before do
-    define_model('Company', name: :string)
+    define_model("Company", name: :string)
 
     FactoryBot.define do
       factory :company
@@ -121,8 +121,8 @@ describe "calling `build_stubbed` with a block" do
   end
 
   it "passes the stub instance" do
-    build_stubbed(:company, name: 'thoughtbot') do |company|
-      expect(company.name).to eq('thoughtbot')
+    build_stubbed(:company, name: "thoughtbot") do |company|
+      expect(company.name).to eq("thoughtbot")
       expect { company.save }.to raise_error(RuntimeError)
     end
   end
@@ -141,29 +141,22 @@ describe "defaulting `created_at`" do
   include FactoryBot::Syntax::Methods
 
   before do
-    define_model('ThingWithTimestamp', created_at: :datetime)
-    define_model('ThingWithoutTimestamp')
+    define_model("ThingWithTimestamp", created_at: :datetime)
+    define_model("ThingWithoutTimestamp")
 
     FactoryBot.define do
       factory :thing_with_timestamp
       factory :thing_without_timestamp
     end
-
-    Timecop.freeze 2012, 1, 1
   end
 
   it "defaults created_at for objects with created_at" do
-    expect(build_stubbed(:thing_with_timestamp).created_at).to eq Time.now
+    expect(build_stubbed(:thing_with_timestamp).created_at).to be_about_now
   end
 
-  it "defaults created_at for objects with created_at to the correct time with zone" do
-    original_timezone = ENV['TZ']
-    ENV['TZ'] = 'UTC'
-    Time.zone = 'Eastern Time (US & Canada)'
-
-    expect(build_stubbed(:thing_with_timestamp).created_at.zone).to eq 'EST'
-
-    ENV['TZ'] = original_timezone
+  it "is doesn't mark the object as changed" do
+    stub = build_stubbed(:thing_with_timestamp)
+    expect(stub).not_to be_changed
   end
 
   it "doesn't add created_at to objects who don't have the method" do
@@ -172,11 +165,39 @@ describe "defaulting `created_at`" do
   end
 
   it "allows overriding created_at for objects with created_at" do
-    expect(build_stubbed(:thing_with_timestamp, created_at: 3.days.ago).created_at).to eq 3.days.ago
+    created_at = 3.days.ago
+    stubbed = build_stubbed(:thing_with_timestamp, created_at: created_at)
+    expect(stubbed.created_at).to eq created_at
   end
 
   it "doesn't allow setting created_at on an object that doesn't define it" do
-    expect { build_stubbed(:thing_without_timestamp, :created_at => Time.now) }.to raise_error(NoMethodError, /created_at=/)
+    expect { build_stubbed(:thing_without_timestamp, created_at: Time.now) }.
+      to raise_error(NoMethodError, /created_at=/)
+  end
+
+  it "allows assignment of created_at" do
+    stub = build_stubbed(:thing_with_timestamp)
+    expect(stub.created_at).to be_about_now
+    past_time = 3.days.ago
+    stub.created_at = past_time
+    expect(stub.created_at).to eq past_time
+  end
+
+  it "behaves the same as a non-stubbed created_at" do
+    define_model("ThingWithCreatedAt", created_at: :datetime) do
+      def created_at
+        :the_real_created_at
+      end
+    end
+
+    FactoryBot.define do
+      factory :thing_with_created_at
+    end
+
+    stub = build_stubbed(:thing_with_created_at)
+    persisted = create(:thing_with_created_at)
+
+    expect(stub.created_at).to eq(persisted.created_at)
   end
 end
 
@@ -191,12 +212,15 @@ describe "defaulting `updated_at`" do
       factory :thing_with_timestamp
       factory :thing_without_timestamp
     end
-
-    Timecop.freeze 2012, 1, 1
   end
 
   it "defaults updated_at for objects with updated_at" do
-    expect(build_stubbed(:thing_with_timestamp).updated_at).to eq Time.current
+    expect(build_stubbed(:thing_with_timestamp).updated_at).to be_about_now
+  end
+
+  it "is doesn't mark the object as changed" do
+    stub = build_stubbed(:thing_with_timestamp)
+    expect(stub).not_to be_changed
   end
 
   it "doesn't add updated_at to objects who don't have the method" do
@@ -205,8 +229,9 @@ describe "defaulting `updated_at`" do
   end
 
   it "allows overriding updated_at for objects with updated_at" do
-    stubbed = build_stubbed(:thing_with_timestamp, updated_at: 3.days.ago)
-    expect(stubbed.updated_at).to eq 3.days.ago
+    past_time = 3.days.ago
+    stubbed = build_stubbed(:thing_with_timestamp, updated_at: past_time)
+    expect(stubbed.updated_at).to eq past_time
   end
 
   it "doesn't allow setting updated_at on an object that doesn't define it" do
@@ -214,18 +239,43 @@ describe "defaulting `updated_at`" do
       build_stubbed(:thing_without_timestamp, updated_at: Time.now)
     end.to raise_error(NoMethodError, /updated_at=/)
   end
+
+  it "allows assignment of updated_at" do
+    stub = build_stubbed(:thing_with_timestamp)
+    expect(stub.updated_at).to be_about_now
+    past_time = 3.days.ago
+    stub.updated_at = past_time
+    expect(stub.updated_at).to eq past_time
+  end
+
+  it "behaves the same as a non-stubbed updated_at" do
+    define_model("ThingWithUpdatedAt", updated_at: :datetime) do
+      def updated_at
+        :the_real_updated_at
+      end
+    end
+
+    FactoryBot.define do
+      factory :thing_with_updated_at
+    end
+
+    stub = build_stubbed(:thing_with_updated_at)
+    persisted = create(:thing_with_updated_at)
+
+    expect(stub.updated_at).to eq(persisted.updated_at)
+  end
 end
 
-describe 'defaulting `id`' do
+describe "defaulting `id`" do
   before do
-    define_model('Post')
+    define_model("Post")
 
     FactoryBot.define do
       factory :post
     end
   end
 
-  it 'allows overriding id' do
+  it "allows overriding id" do
     expect(FactoryBot.build_stubbed(:post, id: 12).id).to eq 12
   end
 end
