@@ -4,49 +4,49 @@ describe "callbacks" do
 
     FactoryBot.define do
       factory :user_with_callbacks, class: :user do
-        after(:stub)   { |user| user.first_name = 'Stubby' }
-        after(:build)  { |user| user.first_name = 'Buildy' }
-        after(:create) { |user| user.last_name  = 'Createy' }
+        after(:stub)   { |user| user.first_name = "Stubby" }
+        after(:build)  { |user| user.first_name = "Buildy" }
+        after(:create) { |user| user.last_name  = "Createy" }
       end
 
       factory :user_with_inherited_callbacks, parent: :user_with_callbacks do
-        after(:stub)  { |user| user.last_name  = 'Double-Stubby' }
-        after(:build) { |user| user.first_name = 'Child-Buildy' }
+        after(:stub)  { |user| user.last_name  = "Double-Stubby" }
+        after(:build) { |user| user.first_name = "Child-Buildy" }
       end
     end
   end
 
   it "runs the after(:stub) callback when stubbing" do
     user = FactoryBot.build_stubbed(:user_with_callbacks)
-    expect(user.first_name).to eq 'Stubby'
+    expect(user.first_name).to eq "Stubby"
   end
 
   it "runs the after(:build) callback when building" do
     user = FactoryBot.build(:user_with_callbacks)
-    expect(user.first_name).to eq 'Buildy'
+    expect(user.first_name).to eq "Buildy"
   end
 
   it "runs both the after(:build) and after(:create) callbacks when creating" do
     user = FactoryBot.create(:user_with_callbacks)
-    expect(user.first_name).to eq 'Buildy'
-    expect(user.last_name).to eq 'Createy'
+    expect(user.first_name).to eq "Buildy"
+    expect(user.last_name).to eq "Createy"
   end
 
   it "runs both the after(:stub) callback on the factory and the inherited after(:stub) callback" do
     user = FactoryBot.build_stubbed(:user_with_inherited_callbacks)
-    expect(user.first_name).to eq 'Stubby'
-    expect(user.last_name).to eq 'Double-Stubby'
+    expect(user.first_name).to eq "Stubby"
+    expect(user.last_name).to eq "Double-Stubby"
   end
 
   it "runs child callback after parent callback" do
     user = FactoryBot.build(:user_with_inherited_callbacks)
-    expect(user.first_name).to eq 'Child-Buildy'
+    expect(user.first_name).to eq "Child-Buildy"
   end
 end
 
-describe 'callbacks using Symbol#to_proc' do
+describe "callbacks using Symbol#to_proc" do
   before do
-    define_model('User') do
+    define_model("User") do
       def confirmed?
         !!@confirmed
       end
@@ -63,7 +63,7 @@ describe 'callbacks using Symbol#to_proc' do
     end
   end
 
-  it 'runs the callback correctly' do
+  it "runs the callback correctly" do
     user = FactoryBot.build(:user)
     expect(user).to be_confirmed
   end
@@ -81,7 +81,7 @@ describe "callbacks using syntax methods without referencing FactoryBot explicit
       factory :user do
         after(:stub)   { generate(:sequence_3) }
         after(:build)  { |user| user.first_number = generate(:sequence_1) }
-        after(:create) { |user, evaluator| user.last_number = generate(:sequence_2) }
+        after(:create) { |user, _evaluator| user.last_number = generate(:sequence_2) }
       end
     end
   end
@@ -144,8 +144,8 @@ describe "custom callbacks" do
 
     FactoryBot.define do
       factory :user do
-        first_name "John"
-        last_name  "Doe"
+        first_name { "John" }
+        last_name  { "Doe" }
 
         before(:custom) { |instance| instance.first_name = "Overridden First" }
         after(:custom)  { |instance| instance.last_name  = "Overridden Last" }
@@ -173,9 +173,9 @@ describe "custom callbacks" do
   end
 end
 
-describe 'binding a callback to multiple callbacks' do
+describe "binding a callback to multiple callbacks" do
   before do
-    define_model('User', name: :string)
+    define_model("User", name: :string)
 
     FactoryBot.define do
       factory :user do
@@ -186,31 +186,31 @@ describe 'binding a callback to multiple callbacks' do
     end
   end
 
-  it 'binds the callback to creation' do
-    expect(FactoryBot.create(:user, name: 'John Doe').name).to eq 'JOHN DOE'
+  it "binds the callback to creation" do
+    expect(FactoryBot.create(:user, name: "John Doe").name).to eq "JOHN DOE"
   end
 
-  it 'does not bind the callback to building' do
-    expect(FactoryBot.build(:user, name: 'John Doe').name).to eq 'John Doe'
+  it "does not bind the callback to building" do
+    expect(FactoryBot.build(:user, name: "John Doe").name).to eq "John Doe"
   end
 
-  it 'binds the callback to stubbing' do
-    expect(FactoryBot.build_stubbed(:user, name: 'John Doe').name).to eq 'JOHN DOE'
+  it "binds the callback to stubbing" do
+    expect(FactoryBot.build_stubbed(:user, name: "John Doe").name).to eq "JOHN DOE"
   end
 end
 
-describe 'global callbacks' do
+describe "global callbacks" do
   include FactoryBot::Syntax::Methods
 
   before do
-    define_model('User', name: :string)
-    define_model('Company', name: :string)
+    define_model("User", name: :string)
+    define_model("Company", name: :string)
 
     FactoryBot.define do
       after :build do |object|
         object.name = case object.class.to_s
-                      when 'User' then 'John Doe'
-                      when 'Company' then 'Acme Suppliers'
+                      when "User" then "John Doe"
+                      when "Company" then "Acme Suppliers"
                       end
       end
 
@@ -242,10 +242,10 @@ describe 'global callbacks' do
     end
   end
 
-  it 'triggers after build callbacks for all factories' do
-    expect(build(:user).name).to eq 'john doe'
-    expect(create(:user).name).to eq 'john doe!!!'
-    expect(create(:user, :awesome).name).to eq 'A___john doe___!!!Z'
-    expect(build(:company).name).to eq 'ACME SUPPLIERS'
+  it "triggers after build callbacks for all factories" do
+    expect(build(:user).name).to eq "john doe"
+    expect(create(:user).name).to eq "john doe!!!"
+    expect(create(:user, :awesome).name).to eq "A___john doe___!!!Z"
+    expect(build(:company).name).to eq "ACME SUPPLIERS"
   end
 end
