@@ -1,10 +1,10 @@
 describe "create multiple instances" do
   before do
-    define_model('Post', title: :string, position: :integer)
+    define_model("Post", title: :string, position: :integer)
 
     FactoryBot.define do
       factory(:post) do |post|
-        post.title "Through the Looking Glass"
+        post.title { "Through the Looking Glass" }
         post.position { rand(10**4) }
       end
     end
@@ -46,7 +46,7 @@ describe "create multiple instances" do
     end
 
     it "uses the new values" do
-      subject.each_with_index do |record, index|
+      subject.each do |record|
         expect(record.position).to eq record.id
       end
     end
@@ -63,26 +63,26 @@ end
 
 describe "multiple creates and transient attributes to dynamically build attribute lists" do
   before do
-    define_model('User', name: :string) do
+    define_model("User", name: :string) do
       has_many :posts
     end
 
-    define_model('Post', title: :string, user_id: :integer) do
+    define_model("Post", title: :string, user_id: :integer) do
       belongs_to :user
     end
 
     FactoryBot.define do
       factory :post do
-        title "Through the Looking Glass"
+        title { "Through the Looking Glass" }
         user
       end
 
       factory :user do
-        name "John Doe"
+        name { "John Doe" }
 
         factory :user_with_posts do
           transient do
-            posts_count 5
+            posts_count { 5 }
           end
 
           after(:create) do |user, evaluator|
