@@ -59,11 +59,11 @@ describe "initialize_with non-ORM-backed objects" do
     end
 
     FactoryBot.define do
-      sequence(:random_data) { 5.times.map { Kernel.rand(200) } }
+      sequence(:random_data) { Array.new(5) { Kernel.rand(200) } }
 
       factory :report_generator do
         transient do
-          name "My Awesome Report"
+          name { "My Awesome Report" }
         end
 
         initialize_with { ReportGenerator.new(name, FactoryBot.generate(:random_data)) }
@@ -93,14 +93,14 @@ describe "initialize_with parent and child factories" do
     FactoryBot.define do
       factory :awesome do
         transient do
-          name "Great"
+          name { "Great" }
         end
 
         initialize_with { Awesome.new(name) }
 
         factory :sub_awesome do
           transient do
-            name "Sub"
+            name { "Sub" }
           end
         end
 
@@ -133,7 +133,7 @@ describe "initialize_with implicit constructor" do
     FactoryBot.define do
       factory :awesome do
         transient do
-          name "Great"
+          name { "Great" }
         end
 
         initialize_with { new(name) }
@@ -178,7 +178,7 @@ describe "initialize_with doesn't duplicate assignment on attributes accessed fr
 end
 
 describe "initialize_with has access to all attributes for construction" do
-  before do
+  it "assigns attributes correctly" do
     define_class("User") do
       attr_reader :name, :email, :ignored
 
@@ -194,7 +194,7 @@ describe "initialize_with has access to all attributes for construction" do
 
       factory :user do
         transient do
-          ignored "of course!"
+          ignored { "of course!" }
         end
 
         email
@@ -204,9 +204,7 @@ describe "initialize_with has access to all attributes for construction" do
         initialize_with { new(attributes) }
       end
     end
-  end
 
-  it "assigns attributes correctly" do
     user_with_attributes = FactoryBot.build(:user)
     expect(user_with_attributes.email).to eq "person1@example.com"
     expect(user_with_attributes.name).to eq "person1"
@@ -214,6 +212,29 @@ describe "initialize_with has access to all attributes for construction" do
   end
 end
 
+describe "initialize_with with an 'attributes' attribute" do
+  it "assigns attributes correctly" do
+    define_class("User") do
+      attr_reader :name
+
+      def initialize(attributes:)
+        @name = attributes[:name]
+      end
+    end
+
+    FactoryBot.define do
+      factory :user do
+        attributes { { name: "Daniel" } }
+        initialize_with { new(attributes) }
+      end
+    end
+
+    user = FactoryBot.build(:user)
+
+    expect(user.name).to eq("Daniel")
+  end
+end
+
 describe "initialize_with for a constructor that requires a block" do
   it "executes the block correctly" do
     define_class("Awesome") do
