@@ -1,10 +1,10 @@
-describe 'FactoryBot.lint' do
-  it 'raises when a factory is invalid' do
-    define_model 'User', name: :string do
+describe "FactoryBot.lint" do
+  it "raises when a factory is invalid" do
+    define_model "User", name: :string do
       validates :name, presence: true
     end
 
-    define_model 'AlwaysValid'
+    define_model "AlwaysValid"
 
     FactoryBot.define do
       factory :user do
@@ -14,11 +14,11 @@ describe 'FactoryBot.lint' do
       factory :always_valid
     end
 
-    error_message = <<-ERROR_MESSAGE.strip
-The following factories are invalid:
+    error_message = <<~ERROR_MESSAGE.strip
+      The following factories are invalid:
 
-* user - Validation failed: Name can't be blank (ActiveRecord::RecordInvalid)
-* admin_user - Validation failed: Name can't be blank (ActiveRecord::RecordInvalid)
+      * user - Validation failed: Name can't be blank (ActiveRecord::RecordInvalid)
+      * admin_user - Validation failed: Name can't be blank (ActiveRecord::RecordInvalid)
     ERROR_MESSAGE
 
     expect do
@@ -26,26 +26,26 @@ The following factories are invalid:
     end.to raise_error FactoryBot::InvalidFactoryError, error_message
   end
 
-  it 'does not raise when all factories are valid' do
-    define_model 'User', name: :string do
+  it "does not raise when all factories are valid" do
+    define_model "User", name: :string do
       validates :name, presence: true
     end
 
     FactoryBot.define do
       factory :user do
-        name 'assigned'
+        name { "assigned" }
       end
     end
 
     expect { FactoryBot.lint }.not_to raise_error
   end
 
-  it 'allows for selective linting' do
-    define_model 'InvalidThing', name: :string do
+  it "allows for selective linting" do
+    define_model "InvalidThing", name: :string do
       validates :name, presence: true
     end
 
-    define_model 'ValidThing', name: :string
+    define_model "ValidThing", name: :string
 
     FactoryBot.define do
       factory :valid_thing
@@ -61,34 +61,6 @@ The following factories are invalid:
     end.not_to raise_error
   end
 
-  it "allows for explicit factories and additional options" do
-    define_model "User", name: :string do
-      validates :name, presence: true
-    end
-
-    FactoryBot.define do
-      factory :user do
-        name "assigned"
-      end
-    end
-
-    FactoryBot.lint FactoryBot.factories, validate_traits: true
-  end
-
-  it "allows for additional options without explicit factories" do
-    define_model "User", name: :string do
-      validates :name, presence: true
-    end
-
-    FactoryBot.define do
-      factory :user do
-        name "assigned"
-      end
-    end
-
-    FactoryBot.lint validate_traits: true
-  end
-
   describe "trait validation" do
     context "enabled" do
       it "raises if a trait produces an invalid object" do
@@ -98,17 +70,17 @@ The following factories are invalid:
 
         FactoryBot.define do
           factory :user do
-            name "Yep"
+            name { "Yep" }
             trait :unnamed do
-              name nil
+              name { nil }
             end
           end
         end
 
-        error_message = <<-ERROR_MESSAGE.strip
-The following factories are invalid:
+        error_message = <<~ERROR_MESSAGE.strip
+          The following factories are invalid:
 
-* user+unnamed - Validation failed: Name can't be blank (ActiveRecord::RecordInvalid)
+          * user+unnamed - Validation failed: Name can't be blank (ActiveRecord::RecordInvalid)
         ERROR_MESSAGE
 
         expect do
@@ -123,9 +95,9 @@ The following factories are invalid:
 
         FactoryBot.define do
           factory :user do
-            name "Yep"
+            name { "Yep" }
             trait :renamed do
-              name "Yessir"
+              name { "Yessir" }
             end
           end
         end
@@ -144,9 +116,9 @@ The following factories are invalid:
 
         FactoryBot.define do
           factory :user do
-            name "Yep"
+            name { "Yep" }
             trait :unnamed do
-              name nil
+              name { nil }
             end
           end
         end
@@ -171,7 +143,7 @@ The following factories are invalid:
 
       FactoryBot.define do
         factory :user do
-          name "Barbara"
+          name { "Barbara" }
         end
       end
 
@@ -191,10 +163,10 @@ The following factories are invalid:
 
       FactoryBot.define do
         factory :user do
-          name "Barbara"
+          name { "Barbara" }
 
           trait :male do
-            name "Bob"
+            name { "Bob" }
           end
         end
       end
@@ -204,4 +176,25 @@ The following factories are invalid:
       end.not_to raise_error
     end
   end
+
+  describe "verbose linting" do
+    it "prints the backtrace for each factory error" do
+      define_class("InvalidThing") do
+        def save!
+          raise "invalid"
+        end
+      end
+
+      FactoryBot.define do
+        factory :invalid_thing
+      end
+
+      expect do
+        FactoryBot.lint(verbose: true)
+      end.to raise_error(
+        FactoryBot::InvalidFactoryError,
+        %r{#{__FILE__}:\d*:in `save!'},
+      )
+    end
+  end
 end
