@@ -2,7 +2,7 @@ describe "modifying factories" do
   include FactoryBot::Syntax::Methods
 
   before do
-    define_model('User', name: :string, admin: :boolean, email: :string, login: :string)
+    define_model("User", name: :string, admin: :boolean, email: :string, login: :string)
 
     FactoryBot.define do
       sequence(:email) { |n| "user#{n}@example.com" }
@@ -15,7 +15,7 @@ describe "modifying factories" do
         end
 
         factory :admin do
-          admin true
+          admin { true }
         end
       end
     end
@@ -25,7 +25,7 @@ describe "modifying factories" do
     before do
       FactoryBot.modify do
         factory :user do
-          name "Great User"
+          name { "Great User" }
         end
       end
     end
@@ -43,7 +43,7 @@ describe "modifying factories" do
     it "does allow the factory to be subsequently modified" do
       FactoryBot.modify do
         factory :user do
-          name "Overridden again!"
+          name { "Overridden again!" }
         end
       end
 
@@ -55,7 +55,7 @@ describe "modifying factories" do
     before do
       FactoryBot.modify do
         factory :user do
-          name "Great User"
+          name { "Great User" }
           after(:create) do |user|
             user.name = user.name.downcase
             user.login = nil
@@ -74,7 +74,7 @@ describe "modifying factories" do
     before do
       FactoryBot.define do
         trait :rockstar do
-          name "Johnny Rockstar!!!"
+          name { "Johnny Rockstar!!!" }
         end
       end
 
@@ -98,7 +98,7 @@ describe "modifying factories" do
       FactoryBot.modify do
         factory :user do
           email { "#{name}-modified@example.com" }
-          name "Great User"
+          name { "Great User" }
         end
       end
     end
@@ -111,14 +111,14 @@ describe "modifying factories" do
         its(:email) { should eq "Great User-modified@example.com" }
       end
 
-      context "overriding dynamic attributes" do
+      context "overriding the email" do
         subject     { create(:user, email: "perfect@example.com") }
 
         its(:name)  { should eq "Great User" }
         its(:email) { should eq "perfect@example.com" }
       end
 
-      context "overriding static attributes" do
+      context "overriding the name" do
         subject     { create(:user, name: "wonderful") }
 
         its(:name)  { should eq "wonderful" }
@@ -135,7 +135,7 @@ describe "modifying factories" do
         its(:admin) { should be true }
       end
 
-      context "overriding dynamic attributes" do
+      context "overriding the email" do
         subject     { create(:admin, email: "perfect@example.com") }
 
         its(:name)  { should eq "Great User" }
@@ -143,7 +143,7 @@ describe "modifying factories" do
         its(:admin) { should be true }
       end
 
-      context "overriding static attributes" do
+      context "overriding the name" do
         subject     { create(:admin, name: "wonderful") }
 
         its(:name)  { should eq "wonderful" }
@@ -156,7 +156,7 @@ describe "modifying factories" do
   it "doesn't overwrite already defined child's attributes" do
     FactoryBot.modify do
       factory :user do
-        admin false
+        admin { false }
       end
     end
     expect(create(:admin)).to be_admin
@@ -165,7 +165,7 @@ describe "modifying factories" do
   it "allows for overriding child classes" do
     FactoryBot.modify do
       factory :admin do
-        admin false
+        admin { false }
       end
     end
 
@@ -173,10 +173,12 @@ describe "modifying factories" do
   end
 
   it "raises an exception if the factory was not defined before" do
-    expect {
+    modify_unknown_factory = -> do
       FactoryBot.modify do
         factory :unknown_factory
       end
-    }.to raise_error(ArgumentError)
+    end
+
+    expect(modify_unknown_factory).to raise_error(KeyError)
   end
 end
