@@ -1,13 +1,13 @@
 describe "attribute overrides" do
   before do
-    define_model('User', admin:   :boolean)
-    define_model('Post', title:   :string,
+    define_model("User", admin:   :boolean)
+    define_model("Post", title:   :string,
                          secure:  :boolean,
                          user_id: :integer) do
       belongs_to :user
 
       def secure=(value)
-        return unless user && user.admin?
+        return unless user&.admin?
         write_attribute(:secure, value)
       end
     end
@@ -15,13 +15,13 @@ describe "attribute overrides" do
     FactoryBot.define do
       factory :user do
         factory :admin do
-          admin true
+          admin { true }
         end
       end
 
       factory :post do
         user
-        title "default title"
+        title { "default title" }
       end
     end
   end
