@@ -1,13 +1,14 @@
-describe 'setting private attributes' do
-  it 'raises a NoMethodError' do
-    define_class('User') do
+describe "setting private attributes" do
+  it "raises a NoMethodError" do
+    define_class("User") do
       private
+
       attr_accessor :foo
     end
 
     FactoryBot.define do
       factory :user do
-        foo 123
+        foo { 123 }
       end
     end
 
