@@ -8,11 +8,11 @@ describe "transient attributes" do
       factory :user do
         transient do
           four     { 2 + 2 }
-          rockstar true
-          upcased  false
+          rockstar { true }
+          upcased  { false }
         end
 
-        name  { "#{FactoryBot.generate(:name)}#{" - Rockstar" if rockstar}" }
+        name  { "#{FactoryBot.generate(:name)}#{' - Rockstar' if rockstar}" }
         email { "#{name.downcase}#{four}@example.com" }
 
         after(:create) do |user, evaluator|
@@ -65,26 +65,6 @@ describe "transient attributes" do
       expect(rockstar.name).to eq "John 1 - Rockstar"
     end
   end
-
-  context "using aliased 'ignore' method name", :silence_deprecation do
-    before do
-      FactoryBot.define do
-        factory :user_using_ignore, class: User do
-          ignore do
-            honorific "Esteemed"
-          end
-
-          name { "#{honorific} Jane Doe" }
-        end
-      end
-    end
-
-    let(:esteemed) { FactoryBot.create(:user_using_ignore) }
-
-    it "uses the default value of the attribute" do
-      expect(esteemed.name).to eq "Esteemed Jane Doe"
-    end
-  end
 end
 
 describe "transient sequences" do
@@ -125,7 +105,7 @@ describe "assigning values from a transient attribute" do
     FactoryBot.define do
       factory :user do
         transient do
-          foo { Foo.new('id-of-foo', 'name-of-foo')}
+          foo { Foo.new("id-of-foo", "name-of-foo") }
         end
 
         foo_id   { foo.id }
@@ -135,8 +115,8 @@ describe "assigning values from a transient attribute" do
   end
 
   it "does not ignore an _id attribute that is an alias for a transient attribute" do
-    user = FactoryBot.build(:user, :foo => Foo.new('passed-in-id-of-foo', 'passed-in-name-of-foo'))
-    expect(user.foo_id).to eq 'passed-in-id-of-foo'
-    expect(user.foo_name).to eq 'passed-in-name-of-foo'
+    user = FactoryBot.build(:user, foo: Foo.new("passed-in-id-of-foo", "passed-in-name-of-foo"))
+    expect(user.foo_id).to eq "passed-in-id-of-foo"
+    expect(user.foo_name).to eq "passed-in-name-of-foo"
   end
 end
