@@ -4,7 +4,7 @@ describe FactoryBot::Attribute::Sequence do
   let(:sequence)      { FactoryBot::Sequence.new(sequence_name, 5) { |n| "Name #{n}" } }
 
   subject { FactoryBot::Attribute::Sequence.new(name, sequence_name, false) }
-  before  { FactoryBot.register_sequence(sequence) }
+  before  { FactoryBot::Internal.register_sequence(sequence) }
 
   its(:name) { should eq name }
 
