@@ -1,126 +1,161 @@
 describe FactoryBot::DefinitionProxy, "#add_attribute" do
-  subject     { FactoryBot::Definition.new }
+  subject     { FactoryBot::Definition.new(:name) }
   let(:proxy) { FactoryBot::DefinitionProxy.new(subject) }
 
-  it "raises if both a block and value are given" do
-    expect {
-      proxy.add_attribute(:something, "great") { "will raise!" }
-    }.to raise_error(FactoryBot::AttributeDefinitionError, "Both value and block given")
-  end
-
-  it "declares a static attribute on the factory" do
-    proxy.add_attribute(:attribute_name, "attribute value")
-    expect(subject).to have_static_declaration(:attribute_name).with_value("attribute value")
-  end
-
   it "declares a dynamic attribute on the factory" do
     attribute_value = -> { "dynamic attribute" }
     proxy.add_attribute(:attribute_name, &attribute_value)
-    expect(subject).to have_dynamic_declaration(:attribute_name).with_value(attribute_value)
+    expect(subject).to have_dynamic_declaration(:attribute_name).
+      with_value(attribute_value)
   end
 end
 
 describe FactoryBot::DefinitionProxy, "#add_attribute when the proxy ignores attributes" do
-  subject     { FactoryBot::Definition.new }
+  subject     { FactoryBot::Definition.new(:name) }
   let(:proxy) { FactoryBot::DefinitionProxy.new(subject, true) }
 
-  it "raises if both a block and value are given" do
-    expect {
-      proxy.add_attribute(:something, "great") { "will raise!" }
-    }.to raise_error(FactoryBot::AttributeDefinitionError, "Both value and block given")
-  end
-
-  it "declares a static attribute on the factory" do
-    proxy.add_attribute(:attribute_name, "attribute value")
-    expect(subject).to have_static_declaration(:attribute_name).ignored.with_value("attribute value")
-  end
-
   it "declares a dynamic attribute on the factory" do
     attribute_value = -> { "dynamic attribute" }
     proxy.add_attribute(:attribute_name, &attribute_value)
-    expect(subject).to have_dynamic_declaration(:attribute_name).ignored.with_value(attribute_value)
+    expect(subject).to have_dynamic_declaration(:attribute_name).
+      ignored.
+      with_value(attribute_value)
   end
 end
 
 describe FactoryBot::DefinitionProxy, "#transient" do
-  subject     { FactoryBot::Definition.new }
+  subject     { FactoryBot::Definition.new(:name) }
   let(:proxy) { FactoryBot::DefinitionProxy.new(subject) }
 
   it "makes all attributes added ignored" do
+    attribute_value = -> { "dynamic_attribute" }
     proxy.transient do
-      add_attribute(:attribute_name, "attribute value")
+      add_attribute(:attribute_name, &attribute_value)
     end
 
-    expect(subject).to have_static_declaration(:attribute_name).ignored.with_value("attribute value")
+    expect(subject).to have_dynamic_declaration(:attribute_name).
+      ignored.
+      with_value(attribute_value)
   end
 end
 
 describe FactoryBot::DefinitionProxy, "#method_missing" do
-  subject     { FactoryBot::Definition.new }
+  subject     { FactoryBot::Definition.new(:name) }
   let(:proxy) { FactoryBot::DefinitionProxy.new(subject) }
 
-  it "declares an implicit declaration without args or a block" do
-    proxy.bogus
-    expect(subject).to have_implicit_declaration(:bogus).with_factory(subject)
+  context "when called without args or a block" do
+    it "declares an implicit declaration" do
+      proxy.bogus
+      expect(subject).to have_implicit_declaration(:bogus).with_factory(subject)
+    end
   end
 
-  it "declares an association when :factory is passed" do
-    proxy.author factory: :user
-    expect(subject).to have_association_declaration(:author).with_options(factory: :user)
+  context "when called with a ':factory' key" do
+    it "declares an association" do
+      proxy.author factory: :user
+      expect(subject).to have_association_declaration(:author).
+        with_options(factory: :user)
+    end
   end
 
-  it "declares a static attribute" do
-    proxy.attribute_name "attribute value"
-    expect(subject).to have_static_declaration(:attribute_name).with_value("attribute value")
+  context "when called with a block" do
+    it "declares a dynamic attribute" do
+      attribute_value = -> { "dynamic attribute" }
+      proxy.attribute_name(&attribute_value)
+      expect(subject).to have_dynamic_declaration(:attribute_name).
+        with_value(attribute_value)
+    end
   end
 
-  it "declares a dynamic attribute" do
-    attribute_value = -> { "dynamic attribute" }
-    proxy.attribute_name(&attribute_value)
-    expect(subject).to have_dynamic_declaration(:attribute_name).with_value(attribute_value)
+  context "when called with a static-attribute-like argument" do
+    it "raises a NoMethodError" do
+      definition = FactoryBot::Definition.new(:broken)
+      proxy = FactoryBot::DefinitionProxy.new(definition)
+
+      invalid_call = -> { proxy.static_attributes_are_gone "true" }
+      expect(invalid_call).to raise_error(
+        NoMethodError,
+        "undefined method 'static_attributes_are_gone' in 'broken' factory\n" \
+        "Did you mean? 'static_attributes_are_gone { \"true\" }'\n",
+      )
+    end
   end
 end
 
 describe FactoryBot::DefinitionProxy, "#sequence" do
-  subject     { FactoryBot::Definition.new }
-  let(:proxy) { FactoryBot::DefinitionProxy.new(subject) }
+  before do
+    allow(FactoryBot::Sequence).to receive(:new).and_call_original
+  end
 
-  before      { allow(FactoryBot::Sequence).to receive(:new) }
+  def build_proxy(factory_name)
+    definition = FactoryBot::Definition.new(factory_name)
+    FactoryBot::DefinitionProxy.new(definition)
+  end
 
   it "creates a new sequence starting at 1" do
-    proxy.sequence(:great)
-    expect(FactoryBot::Sequence).to have_received(:new).with(:great)
+    proxy = build_proxy(:factory)
+
+    proxy.sequence(:sequence)
+
+    expect(FactoryBot::Sequence).to have_received(:new).with(:sequence)
   end
 
   it "creates a new sequence with an overridden starting vaue" do
-    proxy.sequence(:great, "C")
-    expect(FactoryBot::Sequence).to have_received(:new).with(:great, "C")
+    proxy = build_proxy(:factory)
+    override = "override"
+
+    proxy.sequence(:sequence, override)
+
+    expect(FactoryBot::Sequence).to have_received(:new).
+      with(:sequence, override)
   end
 
   it "creates a new sequence with a block" do
     sequence_block = Proc.new { |n| "user+#{n}@example.com" }
-    proxy.sequence(:great, 1, &sequence_block)
-    expect(FactoryBot::Sequence).to have_received(:new).with(:great, 1, &sequence_block)
+    proxy = build_proxy(:factory)
+    proxy.sequence(:sequence, 1, &sequence_block)
+
+    expect(FactoryBot::Sequence).to have_received(:new).
+      with(:sequence, 1, &sequence_block)
   end
 end
 
 describe FactoryBot::DefinitionProxy, "#association" do
-  subject     { FactoryBot::Definition.new }
-  let(:proxy) { FactoryBot::DefinitionProxy.new(subject) }
-
   it "declares an association" do
+    definition = FactoryBot::Definition.new(:definition_name)
+    proxy = FactoryBot::DefinitionProxy.new(definition)
+
     proxy.association(:association_name)
-    expect(subject).to have_association_declaration(:association_name)
+
+    expect(definition).to have_association_declaration(:association_name)
   end
 
   it "declares an association with options" do
-    proxy.association(:association_name, { name: "Awesome" })
-    expect(subject).to have_association_declaration(:association_name).with_options(name: "Awesome")
+    definition = FactoryBot::Definition.new(:definition_name)
+    proxy = FactoryBot::DefinitionProxy.new(definition)
+
+    proxy.association(:association_name, name: "Awesome")
+
+    expect(definition).to have_association_declaration(:association_name).
+      with_options(name: "Awesome")
+  end
+
+  context "when passing a block" do
+    it "raises an error" do
+      definition = FactoryBot::Definition.new(:post)
+      proxy = FactoryBot::DefinitionProxy.new(definition)
+
+      expect { proxy.association(:author) {} }.
+        to raise_error(
+          FactoryBot::AssociationDefinitionError,
+          "Unexpected block passed to 'author' association in 'post' factory",
+        )
+    end
   end
 end
 
 describe FactoryBot::DefinitionProxy, "adding callbacks" do
-  subject        { FactoryBot::Definition.new }
+  subject        { FactoryBot::Definition.new(:name) }
   let(:proxy)    { FactoryBot::DefinitionProxy.new(subject) }
   let(:callback) { -> { "my awesome callback!" } }
 
@@ -159,7 +194,7 @@ describe FactoryBot::DefinitionProxy, "adding callbacks" do
 end
 
 describe FactoryBot::DefinitionProxy, "#to_create" do
-  subject     { FactoryBot::Definition.new }
+  subject     { FactoryBot::Definition.new(:name) }
   let(:proxy) { FactoryBot::DefinitionProxy.new(subject) }
 
   it "accepts a block to run in place of #save!" do
@@ -170,7 +205,7 @@ describe FactoryBot::DefinitionProxy, "#to_create" do
 end
 
 describe FactoryBot::DefinitionProxy, "#factory" do
-  subject     { FactoryBot::Definition.new }
+  subject     { FactoryBot::Definition.new(:name) }
   let(:proxy) { FactoryBot::DefinitionProxy.new(subject) }
 
   it "without options" do
@@ -179,30 +214,30 @@ describe FactoryBot::DefinitionProxy, "#factory" do
   end
 
   it "with options" do
-    proxy.factory(:child, { awesome: true })
+    proxy.factory(:child, awesome: true)
     expect(proxy.child_factories).to include([:child, { awesome: true }, nil])
   end
 
   it "with a block" do
-    child_block = -> { }
+    child_block = -> {}
     proxy.factory(:child, {}, &child_block)
     expect(proxy.child_factories).to include([:child, {}, child_block])
   end
 end
 
 describe FactoryBot::DefinitionProxy, "#trait" do
-  subject     { FactoryBot::Definition.new }
+  subject     { FactoryBot::Definition.new(:name) }
   let(:proxy) { FactoryBot::DefinitionProxy.new(subject) }
 
   it "declares a trait" do
-    male_trait = Proc.new { gender("Male") }
+    male_trait = Proc.new { gender { "Male" } }
     proxy.trait(:male, &male_trait)
     expect(subject).to have_trait(:male).with_block(male_trait)
   end
 end
 
 describe FactoryBot::DefinitionProxy, "#initialize_with" do
-  subject     { FactoryBot::Definition.new }
+  subject     { FactoryBot::Definition.new(:name) }
   let(:proxy) { FactoryBot::DefinitionProxy.new(subject) }
 
   it "defines the constructor on the definition" do
