@@ -13,11 +13,6 @@ describe FactoryBot::EvaluatorClassDefiner do
   end
 
   it "evaluates the block in the context of the evaluator" do
-    dependency_attribute = double(
-      "dependency",
-      name: :dependency,
-      to_proc: -> { 1 },
-    )
     dependency_attribute = stub_attribute(:dependency) { 1 }
     attribute = stub_attribute(:attribute) { dependency + 1 }
     evaluator = define_evaluator(attributes: [dependency_attribute, attribute])
@@ -52,7 +47,7 @@ describe FactoryBot::EvaluatorClassDefiner do
       child_attributes = [stub_attribute, stub_attribute]
       child_evaluator = define_evaluator(
         attributes: child_attributes,
-        parent_class: parent_evaluator_class
+        parent_class: parent_evaluator_class,
       )
 
       expect(child_evaluator.attribute_lists).to eq [parent_attributes, child_attributes]
@@ -67,7 +62,7 @@ describe FactoryBot::EvaluatorClassDefiner do
   def define_evaluator_class(arguments = {})
     evaluator_class_definer = FactoryBot::EvaluatorClassDefiner.new(
       arguments[:attributes] || [],
-      arguments[:parent_class] || FactoryBot::Evaluator
+      arguments[:parent_class] || FactoryBot::Evaluator,
     )
     evaluator_class_definer.evaluator_class
   end
