@@ -1,9 +1,9 @@
 describe FactoryBot::Factory do
   before do
     @name    = :user
-    @class   = define_class('User')
+    @class   = define_class("User")
     @factory = FactoryBot::Factory.new(@name)
-    FactoryBot.register_factory(@factory)
+    FactoryBot::Internal.register_factory(@factory)
   end
 
   it "has a factory name" do
@@ -14,21 +14,9 @@ describe FactoryBot::Factory do
     expect(@factory.build_class).to eq @class
   end
 
-  it "passes a custom creation block" do
-    strategy = double("strategy", result: nil, add_observer: true)
-    allow(FactoryBot::Strategy::Build).to receive(:new).and_return strategy
-    block = -> {}
-    factory = FactoryBot::Factory.new(:object)
-    factory.to_create(&block)
-
-    factory.run(FactoryBot::Strategy::Build, {})
-
-    expect(strategy).to have_received(:result).with(instance_of(FactoryBot::Evaluation))
-  end
-
   it "returns associations" do
     factory = FactoryBot::Factory.new(:post)
-    FactoryBot.register_factory(FactoryBot::Factory.new(:admin))
+    FactoryBot::Internal.register_factory(FactoryBot::Factory.new(:admin))
     factory.declare_attribute(FactoryBot::Declaration::Association.new(:author, {}))
     factory.declare_attribute(FactoryBot::Declaration::Association.new(:editor, {}))
     factory.declare_attribute(FactoryBot::Declaration::Implicit.new(:admin, factory))
@@ -44,7 +32,7 @@ describe FactoryBot::Factory do
 
     factory = FactoryBot::Factory.new(:post)
     factory.declare_attribute(association_on_parent)
-    FactoryBot.register_factory(factory)
+    FactoryBot::Internal.register_factory(factory)
 
     child_factory = FactoryBot::Factory.new(:child_post, parent: :post)
     child_factory.declare_attribute(association_on_child)
@@ -55,25 +43,21 @@ describe FactoryBot::Factory do
   describe "when overriding generated attributes with a hash" do
     before do
       @name  = :name
-      @value = 'The price is right!'
+      @value = "The price is right!"
       @hash  = { @name => @value }
     end
 
     it "returns the overridden value in the generated attributes" do
-      declaration = FactoryBot::Declaration::Static.new(@name, 'The price is wrong, Bob!')
+      declaration =
+        FactoryBot::Declaration::Dynamic.new(@name, false, -> { flunk })
       @factory.declare_attribute(declaration)
       result = @factory.run(FactoryBot::Strategy::AttributesFor, @hash)
       expect(result[@name]).to eq @value
     end
 
-    it "does not call a lazy attribute block for an overridden attribute" do
-      declaration = FactoryBot::Declaration::Dynamic.new(@name, false, -> { flunk })
-      @factory.declare_attribute(declaration)
-      @factory.run(FactoryBot::Strategy::AttributesFor, @hash)
-    end
-
     it "overrides a symbol parameter with a string parameter" do
-      declaration = FactoryBot::Declaration::Static.new(@name, 'The price is wrong, Bob!')
+      declaration =
+        FactoryBot::Declaration::Dynamic.new(@name, false, -> { flunk })
       @factory.declare_attribute(declaration)
       @hash = { @name.to_s => @value }
       result = @factory.run(FactoryBot::Strategy::AttributesFor, @hash)
@@ -83,14 +67,20 @@ describe FactoryBot::Factory do
 
   describe "overriding an attribute with an alias" do
     before do
-      @factory.declare_attribute(FactoryBot::Declaration::Static.new(:test, 'original'))
+      attribute = FactoryBot::Declaration::Dynamic.new(
+        :test,
+        false, -> { "original" }
+      )
+      @factory.declare_attribute(attribute)
       FactoryBot.aliases << [/(.*)_alias/, '\1']
-      @result = @factory.run(FactoryBot::Strategy::AttributesFor,
-                             test_alias: 'new')
+      @result = @factory.run(
+        FactoryBot::Strategy::AttributesFor,
+        test_alias: "new",
+      )
     end
 
     it "uses the passed in value for the alias" do
-      expect(@result[:test_alias]).to eq 'new'
+      expect(@result[:test_alias]).to eq "new"
     end
 
     it "discards the predefined value for the attribute" do
@@ -158,7 +148,7 @@ describe FactoryBot::Factory, "with a name ending in s" do
   let(:name)           { :business }
   let(:business_class) { Business }
 
-  before  { define_class('Business') }
+  before  { define_class("Business") }
   subject { FactoryBot::Factory.new(name) }
 
   its(:name)        { should eq name }
@@ -224,18 +214,22 @@ describe FactoryBot::Factory, "human names" do
 end
 
 describe FactoryBot::Factory, "running a factory" do
-  subject              { FactoryBot::Factory.new(:user) }
-  let(:attribute)      { FactoryBot::Attribute::Static.new(:name, "value", false) }
-  let(:declaration)    { FactoryBot::Declaration::Static.new(:name, "value", false) }
+  subject { FactoryBot::Factory.new(:user) }
+  let(:attribute) do
+    FactoryBot::Attribute::Dynamic.new(:name, false, -> { "value" })
+  end
+  let(:declaration) do
+    FactoryBot::Declaration::Dynamic.new(:name, false, -> { "value" })
+  end
   let(:strategy) { double("strategy", result: "result", add_observer: true) }
-  let(:attributes)     { [attribute] }
+  let(:attributes) { [attribute] }
   let(:attribute_list) do
     double("attribute-list", declarations: [declaration], to_a: attributes)
   end
 
   before do
     define_model("User", name: :string)
-    allow(FactoryBot::Declaration::Static).to receive(:new).
+    allow(FactoryBot::Declaration::Dynamic).to receive(:new).
       and_return declaration
     allow(declaration).to receive(:to_attributes).and_return attributes
     allow(FactoryBot::Strategy::Build).to receive(:new).and_return strategy
@@ -253,8 +247,8 @@ describe FactoryBot::Factory, "running a factory" do
 
   it "calls the block and returns the result" do
     block_run = nil
-    block = ->(result) { block_run = "changed" }
-    subject.run(FactoryBot::Strategy::Build, { }, &block)
+    block = ->(_result) { block_run = "changed" }
+    subject.run(FactoryBot::Strategy::Build, {}, &block)
     expect(block_run).to eq "changed"
   end
 end
