@@ -26,7 +26,7 @@ describe "definition loading" do
   def self.in_directory_with_files(*files)
     before do
       @pwd = Dir.pwd
-      @tmp_dir = File.join(File.dirname(__FILE__), 'tmp')
+      @tmp_dir = File.join(File.dirname(__FILE__), "tmp")
       FileUtils.mkdir_p @tmp_dir
       Dir.chdir(@tmp_dir)
 
@@ -43,30 +43,30 @@ describe "definition loading" do
   end
 
   describe "with factories.rb" do
-    in_directory_with_files 'factories.rb'
+    in_directory_with_files "factories.rb"
     it_should_behave_like "finds definitions" do
-      it { should load_definitions_from('factories.rb') }
+      it { should load_definitions_from("factories.rb") }
     end
   end
 
   %w(spec test).each do |dir|
     describe "with a factories file under #{dir}" do
-      in_directory_with_files File.join(dir, 'factories.rb')
+      in_directory_with_files File.join(dir, "factories.rb")
       it_should_behave_like "finds definitions" do
         it { should load_definitions_from("#{dir}/factories.rb") }
       end
     end
 
     describe "with a factories file under #{dir}/factories" do
-      in_directory_with_files File.join(dir, 'factories', 'post_factory.rb')
+      in_directory_with_files File.join(dir, "factories", "post_factory.rb")
       it_should_behave_like "finds definitions" do
         it { should load_definitions_from("#{dir}/factories/post_factory.rb") }
       end
     end
 
     describe "with several factories files under #{dir}/factories" do
-      in_directory_with_files File.join(dir, 'factories', 'post_factory.rb'),
-                              File.join(dir, 'factories', 'person_factory.rb')
+      in_directory_with_files File.join(dir, "factories", "post_factory.rb"),
+                              File.join(dir, "factories", "person_factory.rb")
       it_should_behave_like "finds definitions" do
         it { should load_definitions_from("#{dir}/factories/post_factory.rb") }
         it { should load_definitions_from("#{dir}/factories/person_factory.rb") }
@@ -74,8 +74,8 @@ describe "definition loading" do
     end
 
     describe "with several factories files under #{dir}/factories in non-alphabetical order" do
-      in_directory_with_files File.join(dir, 'factories', 'b.rb'),
-                              File.join(dir, 'factories', 'a.rb')
+      in_directory_with_files File.join(dir, "factories", "b.rb"),
+                              File.join(dir, "factories", "a.rb")
       it "loads the files in the right order" do
         allow(FactoryBot).to receive(:load)
         wd = File.dirname(__FILE__)
@@ -90,9 +90,9 @@ describe "definition loading" do
     end
 
     describe "with nested and unnested factories files under #{dir}" do
-      in_directory_with_files File.join(dir, 'factories.rb'),
-                              File.join(dir, 'factories', 'post_factory.rb'),
-                              File.join(dir, 'factories', 'person_factory.rb')
+      in_directory_with_files File.join(dir, "factories.rb"),
+                              File.join(dir, "factories", "post_factory.rb"),
+                              File.join(dir, "factories", "person_factory.rb")
       it_should_behave_like "finds definitions" do
         it { should load_definitions_from("#{dir}/factories.rb") }
         it { should load_definitions_from("#{dir}/factories/post_factory.rb") }
@@ -101,8 +101,8 @@ describe "definition loading" do
     end
 
     describe "with deeply nested factory files under #{dir}" do
-      in_directory_with_files File.join(dir, 'factories', 'subdirectory', 'post_factory.rb'),
-                              File.join(dir, 'factories', 'subdirectory', 'person_factory.rb')
+      in_directory_with_files File.join(dir, "factories", "subdirectory", "post_factory.rb"),
+                              File.join(dir, "factories", "subdirectory", "person_factory.rb")
       it_should_behave_like "finds definitions" do
         it { should load_definitions_from("#{dir}/factories/subdirectory/post_factory.rb") }
         it { should load_definitions_from("#{dir}/factories/subdirectory/person_factory.rb") }
