@@ -1,10 +1,9 @@
-require 'rspec'
-require 'rspec/its'
+require "rspec"
+require "rspec/its"
 
 require "simplecov"
 
-require 'factory_bot'
-require "timecop"
+require "factory_bot"
 
 Dir["spec/support/**/*.rb"].each { |f| require File.expand_path(f) }
 
@@ -22,10 +21,8 @@ RSpec.configure do |config|
     FactoryBot.reload
   end
 
-  config.after do
-    Timecop.return
-  end
-
   config.order = :random
   Kernel.srand config.seed
+
+  config.example_status_persistence_file_path = "tmp/rspec_examples.txt"
 end
