@@ -14,7 +14,7 @@ RSpec::Matchers.define :delegate do |delegated_method|
   match do |instance|
     @instance = instance
     @args ||= []
-    return_value = 'stubbed return value'
+    return_value = "stubbed return value"
     method_on_target = @method_on_target || delegated_method
     stubbed_target = double("stubbed_target", method_on_target => return_value)
     allow(@instance).to receive(@target_method).and_return stubbed_target
@@ -28,10 +28,10 @@ RSpec::Matchers.define :delegate do |delegated_method|
   failure_message do
     if Class === @instance
       message = "expected #{@instance.name} "
-      prefix = '.'
+      prefix = "."
     else
       message = "expected #{@instance.class.name} "
-      prefix = '#'
+      prefix = "#"
     end
     message << "to delegate #{prefix}#{delegated_method} to #{prefix}#{@target_method}"
     if @method_on_target
